# portfolio-carousel

Streamlit component that allows you to do X

## Installation instructions 

```sh
pip install portfolio-carousel
```

## Usage instructions

```python
import streamlit as st

from portfolio_carousel import portfolio_carousel

value = portfolio_carousel()

st.write(value)
